@@ -1,13 +1,15 @@
 package Exporter::Handy::Util;
 
 # ABSTRACT: Routines useful when exporting symbols thru Exporter and friends
-our $VERSION = '0.001000';
+our $VERSION = '0.200000';
 
 use v5.14;
 use strict;
 use warnings;
 
-use List::Util qw( pairs uniq );
+use Data::Printer;
+
+use List::Util qw( pairs unpairs uniq );
 use Exporter::Extensible -exporter_setup => 1;
 
 export(qw(
@@ -19,18 +21,20 @@ export(qw(
 # Generators for exported functions
 sub _generate_xtags {
   my ($exporter, $symbol, $opts) = @_;
-  sub {; xtags($opts, @_ ) } # curried
+  sub {; xtags($opts // {}, @_ ) } # curried
 }
 
 sub _generate_expand_xtags {
   my ($exporter, $symbol, $opts) = @_;
-  sub {; expand_xtags(@_, $opts ) } # curried
+  sub {; expand_xtags(@_, $opts // { }) } # curried
 }
 
 
 
 
 sub xtags { # useful for building export tags
+  # say STDERR 'xtag ARGS: ' . np(@_);
+
   my %opt;   %opt  = ( %opt,  %{; shift   } ) while _is_plain_hashref($_[0]);  # merge options given by any leading hash-refs
   my @res;
 
@@ -48,6 +52,8 @@ sub xtags { # useful for building export tags
 }
 
 sub _xtag_group {
+  # say STDERR '_xtag_group ARGS: ' . np(@_);
+
   # options may be given by one or more leading hash-refs (that we merge)
   my %opt;  %opt = ( %opt, %{; shift } ) while _is_plain_hashref($_[0]);
 
@@ -57,8 +63,11 @@ sub _xtag_group {
 
   $group    = $group // delete $opt{group} // delete $opt{name} // '';
   $group    =~ s/^([:])//;
+
+  my %subopt= %opt;
   my $sig   = delete $opt{sig} // $1 // '';  # like a sigil... It's typically either ':' or empty string.
   my $sep   = delete $opt{sep} // '_';
+  my $nogroup   = delete $opt{nogroup} // 0;
 
   my @pfx   = _flat( delete $opt{pfx} // ( $group ? "${group}${sep}" : "" ));
 
@@ -69,13 +78,25 @@ sub _xtag_group {
     for my $k (sort keys %items) {
       my $v  = $items{$k};
       $k =~ s/^\Q$sig\E//;
-      $tags{"${pfx}${k}"} = $v;
+      my $key = "${pfx}${k}";
+      my %subtags = ( ref($v) =~ /^HASH$/ ) ? ( _xtag_group(\%subopt, $key => $v) ) : ( $key => $v);
+      %tags = (%tags, %subtags);
     }
   }
   # umbrella entry (that encompasses all subtags)
-  $tags{$group} = [ map {; $_//'' ? (":$_") : () } ( sort keys %tags ) ] if $group;
+  if (!$nogroup && defined $group && $group) {
+    my $g = $group;
+    $g = $sig . $g if $sig && ($g !~ /^\Q$sig\E/);
+    $tags{$g} = [
+      map {;
+        my $item = $_;
+        $item = ':' . $_ if defined $_ && $_ && !m/^[:]/;
+        $item // ()
+      } ( sort keys %tags ) ]
+  }
 
-  wantarray ? %tags : \%tags; ## no critic
+  my @tags = _kv_sort(%tags);  # sort on keys
+  wantarray ? @tags : \@tags; ## no critic
 }
 
 
@@ -127,7 +148,7 @@ sub _is_plain_scalarref { ref( $_[0] ) eq 'SCALAR' }
 sub _is_plain_scalar    { !ref( $_[0] ) }
 
 # List
-sub _flat  { # shamelessly copied from: [List::Flat](https://metacpan.org/pod/List::Flat)
+sub _flat  { # shamelessly copied from: [List::_flat](https://metacpan.org/pod/List::_flat)
   my @results;
 
   while (@_) {
@@ -141,6 +162,10 @@ sub _flat  { # shamelessly copied from: [List::Flat](https://metacpan.org/pod/Li
   return wantarray ? @results : \@results;  ## no critic
 }
 
+sub _kv_sort {
+  unpairs sort { $a->[0] cmp $b->[0] } pairs(@_)
+}
+
 1;
 
 __END__
@@ -157,7 +182,7 @@ Exporter::Handy::Util - Routines useful when exporting symbols thru Exporter and
 
 =head1 VERSION
 
-version 0.001000
+version 0.200000
 
 =head1 SYNOPSIS
 
